# Release information about TGScheduler

version = "1.6.3"

description = "TurboGears Scheduler"
long_description = """This scheduler package is based on the TurboGears 1
built-in scheduler which is based on the Kronos by Irmen de Jong.
The scheduler makes it easy to have one-time or recurring tasks run as needed."""
author = "Vince Spicer"
email = "vinces1979@gmail.com"

url = "http://tgscheduler.googlecode.com"
license = "MIT"
